@@ -1,7 +1,7 @@
 package Inline::Filters;
 use strict;
 use Config;
-$Inline::Filters::VERSION = "0.12_03";
+$Inline::Filters::VERSION = "0.12";
 
 #============================================================================
 # Object Interface
@@ -29,7 +29,7 @@ sub Strip_POD {
 #============================================================================
 # Strip comments in various languages
 #============================================================================
-sub _skip_quoted {
+sub skip_quoted {
     my ($text, $index, $closer) = @_;
     for (my $i=$index+1; $i<length $text; $i++) {
         my $p = substr($text, $i-1, 1);
@@ -39,14 +39,14 @@ sub _skip_quoted {
     return $index; # must not have been a string
 }
 
-sub _strip_comments {
+sub strip_comments {
     my ($txt, $opn, $cls, @quotes) = @_;
     my $i = -1;
     while (++$i < length $txt) {
 	my $closer;
         if (grep {my $r=substr($txt,$i,length($_)) eq $_; $closer=$_ if $r; $r}
 	    @quotes) {
-	    $i = _skip_quoted($txt, $i, $closer);
+	    $i = skip_quoted($txt, $i, $closer);
 	    next;
         }
         if (substr($txt, $i, length($opn)) eq $opn) {
@@ -64,23 +64,23 @@ sub _strip_comments {
 sub Strip_C_Comments {
     my $ilsm = shift;
     my $code = shift;
-    $code = _strip_comments($code, '//', "\n", '"');
-    $code = _strip_comments($code, '/*', '*/', '"');
+    $code = strip_comments($code, '//', "\n", '"');
+    $code = strip_comments($code, '/*', '*/', '"');
     return $code;
 }
 
 sub Strip_CPP_Comments {
     my $ilsm = shift;
     my $code = shift;
-    $code = _strip_comments($code, '//', "\n", '"');
-    $code = _strip_comments($code, '/*', '*/', '"');
+    $code = strip_comments($code, '//', "\n", '"');
+    $code = strip_comments($code, '/*', '*/', '"');
     return $code;
 }
 
 sub Strip_Python_Comments {
     my $ilsm = shift;
     my $code = shift;
-    $code = _strip_comments($code, '#', "\n", '"', '"""', '\'');
+    $code = strip_comments($code, '#', "\n", '"', '"""', '\'');
     return $code;
 }
 
@@ -97,24 +97,10 @@ sub Strip_TCL_Comments {
 sub Preprocess {
     my $ilsm = shift;
     my $code = shift;
-
-    my @inc_array;
-    if (defined($ilsm->{ILSM}{MAKEFILE}{INC})) {
-      if (ref($ilsm->{ILSM}{MAKEFILE}{INC} eq 'ARRAY')) {
-        @inc_array = @{$ilsm->{ILSM}{MAKEFILE}{INC}};
-      }
-      else {
-        @inc_array = ($ilsm->{ILSM}{MAKEFILE}{INC});
-      }
-    }
-    else {
-      @inc_array = ();
-    }
-
     my $cpp = join ' ', ($Config{cpprun},
 			 $Config{cppflags},
 			 "-I$Config{archlibexp}/CORE",
-                         @inc_array
+			 @{$ilsm->{ILSM}{MAKEFILE}{INC}||[]}
 			);
 
     my $tmpfile = $ilsm->{API}{build_dir} . "/Filters.c";
@@ -148,7 +134,6 @@ my %filters =
 	    Strip_Comments => \&Strip_CPP_Comments,
 	   ],
   );
-
 sub get_filters {
     my $language = shift;
     my ($all, $lang) = @filters{ALL => $language};
